=========
Changelog
=========

Version 0.1.0
=============

- First release of xgboost-distribution package
- Contains XGBDistribution estimator, an xgboost wrapper with natural gradients
- Normal distribution implemented
